@@ -65,8 +65,6 @@ LayoutCandidate(MUIMSessionHandle inHandle)
     qdY = tsmStat.fReplyPoint.v;
   }
 
-  //DEBUG_PRINT("LayoutCandidate() x=%hd y=%hd\n", qdX, qdY);
-
   ShowCandidateWindow(inHandle, qdX, qdY);
 }
 
@@ -84,9 +82,6 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
   //char buf[BUFSIZ];
   //CFIndex len;
 
-  DEBUG_PRINT("InitCandidateWindow() fBundleRef=%p\n",
-              (*inHandle)->fBundleRef);
-
   if ((*inHandle)->fBundleRef) return noErr;
 
   appBundle = CFBundleGetMainBundle();
@@ -133,11 +128,9 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
   funcPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
                                               CFSTR("initializeBundle"));
   require(funcPtr, CantFindFunction);
-  DEBUG_PRINT("Initializebundle() CFBundleGetFunctionPointerForName('initializeBundle') OK\n");
 
   res = (*funcPtr)(HandleBundleCommand);
   require_noerr(res, CantInitializeBundle);
-  DEBUG_PRINT("Initializebundle() initializebundle() OK\n");
                 
  CantCreateBundleURL:
  CantCreateBundle:
@@ -257,11 +250,6 @@ TrimIndex(MUIMSessionHandle inHandle)
 {
   Boolean changed = false;
 
-  DEBUG_PRINT("TrimIndex() fCandidateIndex=%ld fLayoutBegin=%lu fDisplayLimit=%lu\n",
-              (*inHandle)->fCandidateIndex,
-              (*inHandle)->fLayoutBegin,
-              (*inHandle)->fDisplayLimit);
-
   if ((*inHandle)->fDisplayLimit != 0) {
     while ((*inHandle)->fLayoutBegin + (*inHandle)->fDisplayLimit
            <= (*inHandle)->fCandidateIndex) {
@@ -293,11 +281,6 @@ TrimIndex(MUIMSessionHandle inHandle)
     }
   }
 
-  DEBUG_PRINT("TrimIndex() [updated] fCandidateIndex=%ld fLayoutBegin=%lu fDisplayLimit=%lu\n",
-              (*inHandle)->fCandidateIndex,
-              (*inHandle)->fLayoutBegin,
-              (*inHandle)->fDisplayLimit);
-
   return changed;
 }
 
@@ -311,6 +294,7 @@ UpdateCandidate(MUIMSessionHandle inHandle)
   
   clearCandPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
                                                    CFSTR("clearCandidate"));
+
   if (addCandPtr)
     res = (*clearCandPtr)();
 
