@@ -201,10 +201,10 @@ MUIMInitialize(ComponentInstance inComponentInstance,
   if (refNum != -1)
     CloseComponentResFile(refNum);
 
-#if 0 // XXX
+  /*
   if (result == noErr)
     result = MUIMInitializeMessageReceiving();
-#endif
+  */
 
   return result;
 }
@@ -277,6 +277,11 @@ MUIMSessionOpen(ComponentInstance inComponentInstance,
     (**outSessionHandle)->fMode =
       uim_get_current_mode((**outSessionHandle)->fUC);
 
+    (**outSessionHandle)->fLastUpdateLength = 0;
+    (**outSessionHandle)->fFixBuffer = NULL;
+    (**outSessionHandle)->fFixLen = 0;
+    (**outSessionHandle)->fOldPreedit = NULL;
+
     (**outSessionHandle)->fBundleRef = NULL;
 
     (**outSessionHandle)->fWindowOpened = false;
@@ -314,6 +319,9 @@ MUIMSessionActivate(MUIMSessionHandle inSessionHandle)
 
   gActiveSession = inSessionHandle;
 
+  long keyboardID = GetScriptVariable(GetScriptManagerVariable(smLastScript), smScriptKeys);
+  SetScriptVariable (smJapanese, smScriptKeys, keyboardID);
+
   DEBUG_PRINT("MUIMSessionActivate() gActiveSession=%p\n",
               gActiveSession);
 
@@ -375,8 +383,12 @@ MUIMSessionEvent(MUIMSessionHandle inSessionHandle, EventRef inEventRef)
     GetEventParameter(inEventRef, kEventParamKeyModifiers, typeUInt32, nil,
                       sizeof(modifiers), nil, &modifiers);
 
-    handled = MUIMHandleInput(inSessionHandle, charCode);
+    DEBUG_PRINT("MUIMSessionEvent() keycode=%lx, char=%c, charCode=%x, modifiers=%lx\n",
+                keyCode, charCode, charCode, modifiers);
+
+    handled = MUIMHandleInput(inSessionHandle, keyCode, charCode, modifiers);
   }
+
   return handled;
 }
 
@@ -403,7 +415,7 @@ MUIMGetActiveSession(void)
 }
 
 Boolean
-MUIMHandleInput(MUIMSessionHandle inSessionHandle, unsigned char inCharCode)
+MUIMHandleInput(MUIMSessionHandle inSessionHandle, UInt32 inKeycode, unsigned char inCharCode, UInt32 inModifiers)
 {
   Boolean handled;
   int key = 0, mod = 0;
@@ -411,39 +423,46 @@ MUIMHandleInput(MUIMSessionHandle inSessionHandle, unsigned char inCharCode)
 
   handled = FALSE;
 
-  DEBUG_PRINT("MUIMHandleInput() inCharCode=%02x\n", inCharCode);
+  DEBUG_PRINT("MUIMHandleInput() inCharCode=%02x inModifiers=%lx\n", inCharCode, inModifiers);
 
-  switch (inCharCode) {
-  case 0x03:
+  switch (inKeycode) {
+  case 0x24:
+  case 0x34:
     key = UKey_Return;
     break;
-
-  case 0x08:
+  case 0x33:
     key = UKey_Backspace;
     break;
-
-  case 0x1c:
+  case 0x35:
+    key = UKey_Escape;
+    break;
+  case 0x73:
+    key = UKey_Home;
+    break;
+  case 0x74:
+    key = UKey_Prior;
+    break;
+  case 0x77:
+    key = UKey_End;
+    break;
+  case 0x79:
+    key = UKey_Next;
+    break;
+  case 0x7b:
     key = UKey_Left;
     break;
-
-  case 0x1d:
+  case 0x7c:
     key = UKey_Right;
     break;
-
-  case 0x1e:
-    key = UKey_Up;
-    break;
-
-  case 0x1f:
+  case 0x7d:
     key = UKey_Down;
     break;
-
+  case 0x7e:
+    key = UKey_Up;
+    break;
   default:
     key = ConvertKeyVal(inCharCode);
-    if (key == UKey_Zenkaku_Hankaku)
-      mod = 0;
-    else
-      mod = ConvertModifier(inCharCode);
+    mod = ConvertModifier(inModifiers);
     break;
   }
 
@@ -453,9 +472,18 @@ MUIMHandleInput(MUIMSessionHandle inSessionHandle, unsigned char inCharCode)
   DEBUG_PRINT("MUIMHandleInput() uim_press_key ret=%d\n", rv);
 
   uim_release_key((*inSessionHandle)->fUC, key, mod);
-  if (!rv)
+
+  if (!rv) {
     handled = TRUE;
 
+    if ((*inSessionHandle)->fFixLen > 0) {
+      MUIMUpdateActiveInputArea(inSessionHandle, TRUE);
+      free((*inSessionHandle)->fFixBuffer);
+      (*inSessionHandle)->fFixBuffer = NULL;
+      (*inSessionHandle)->fFixLen = 0;
+    }
+  }
+
   return handled;
 }
 
@@ -543,27 +571,20 @@ ConvertKeyVal(int inKey)
 {
   DEBUG_PRINT("ConvertKeyVal() inKey=%02x\n", inKey);
 
-  switch (inKey) {
-  case 0x08:
-    return UKey_Backspace;
-  case 0x0a:
-    return UKey_Zenkaku_Hankaku;
-  case 0x0d:
-    return UKey_Return;
-  case 0x1b:
-    return UKey_Escape;
-  }
+  if (inKey >= 0x01 && inKey <= 0x1a)
+    return inKey + 0x60;
   return inKey;
 }
 
 static int
 ConvertModifier(int inMod)
 {
-  DEBUG_PRINT("ConvertModifier() inMod=%02x\n", inMod);
+  DEBUG_PRINT("ConvertModifier() inMod=%lx\n", inMod);
+
+  if (inMod == 0x200)
+    return UMod_Shift;
+  if (inMod == 0x1000)
+    return UMod_Control;
 
-  if (inMod >= 0x41 && inMod <= 0x5a)
-    return UKey_Shift;
-  if (inMod >= 0x01 && inMod <= 0x1a)
-    return UKey_Control;
   return 0;
 }
