@@ -61,6 +61,8 @@ typedef struct _MUIMSessionRecord
   UniCharPtr fFixBuffer;
   UInt32 fFixLen;
 
+  UniCharPtr fOldPreedit;
+
   SInt32 fNRCandidates;
   SInt32 fCandidateIndex;
   SInt32 fLayoutBegin;
@@ -118,7 +120,7 @@ MUIMSessionHandle
 MUIMGetActiveSession(void);
 
 Boolean
-MUIMHandleInput(MUIMSessionHandle inSessionHandle, unsigned char inCharCode);
+MUIMHandleInput(MUIMSessionHandle inSessionHandle, UInt32 inKeycode, unsigned char inCharCode, UInt32 inModifiers);
 
 void
 MUIMLog(unsigned char *message);
