@@ -66,14 +66,25 @@ MUIMUpdateActiveInputArea(MUIMSessionHandle inHandle, Boolean inFix)
 
   if (!inFix) {
     GetPreeditString(inHandle, &str, &len, &cursorPos);
+
+    if ((*inHandle)->fOldPreedit != NULL &&
+        !memcmp((*inHandle)->fOldPreedit, str, sizeof(UniChar) * len)) {
+      free(str);
+      return noErr;
+    }
+    free((*inHandle)->fOldPreedit);
+    (*inHandle)->fOldPreedit = str;
     fixLen = 0;
   }
   else {
     len = cursorPos = (*inHandle)->fFixLen;
     fixLen = len * sizeof(UniChar);
+    str = (*inHandle)->fFixBuffer;
+    /*
     str = (UniCharPtr) malloc(fixLen + sizeof(UniChar));
     memcpy(str, (*inHandle)->fFixBuffer, fixLen);
     str[len] = '\0';
+    */
   }
 
   DEBUG_PRINT("MUIMUpdateActiveInputArea() inFix=%s len=%lu cursorPos=%lu fixLen=%ld\n",
@@ -205,7 +216,7 @@ MUIMUpdateActiveInputArea(MUIMSessionHandle inHandle, Boolean inFix)
   DisposePtr((Ptr) hiliteRangePtr);
   DisposePtr((Ptr) updateRangePtr);
 
-  free(str);
+  //free(str);
 
   return error;
 }
