@@ -48,6 +48,8 @@ AddPreeditSegment(MUIMSessionHandle inHandle, int inAttr,
 void
 UIMCommitString(void *ptr, char *str)
 {
+  DEBUG_PRINT("UIMCommitString() len=%d\n", strlen(str));
+
   MUIMSessionHandle handle = (MUIMSessionHandle) ptr;
   CFMutableStringRef cf_string;
 
@@ -68,12 +70,6 @@ UIMCommitString(void *ptr, char *str)
     DumpString("utf16", (char *) (*handle)->fFixBuffer,
     (*handle)->fFixLen * sizeof(UniChar));
   */
-
-  MUIMUpdateActiveInputArea(handle, true);
-
-  free((*handle)->fFixBuffer);
-  (*handle)->fFixBuffer = NULL;
-  (*handle)->fFixLen = 0;
 }
 
 void
@@ -140,7 +136,7 @@ UIMPreeditPushback(void *ptr, int attr, char *str)
 #endif
 
   if (!strcmp(str, "")
-      && !(attr & (UPreeditAttr_Cursor | UPreeditAttr_Separator)))
+      && !(attr & (UPreeditAttr_Cursor | UPreeditAttr_Separator | UPreeditAttr_UnderLine)))
     return;
 
   AddPreeditSegment(handle, attr, str);
