@@ -1,11 +1,13 @@
 #!/bin/sh
 
+dest="Package/Package_contents/Library/Components"
+
 xcodebuild -target CandidateController clean
 xcodebuild -target MacUIM clean
 
 xcodebuild -buildstyle Deployment -target CandidateController || exit 1
 xcodebuild -buildstyle Deployment -target MacUIM || exit 1
 
-rm -rfv Package/Package_contents/Library/Components/MacUIM.component
+rm -rf ${dest}/MacUIM.component
 
-mv -v build/MacUIM.component Package/Package_contents/Library/Components
+mv -v build/MacUIM.component ${dest}
